/*
 * ErrorView.java
 *
 * Copyright (c) 2011 Tad Hardesty
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */
package com.platymuus.mcurl;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;
import java.net.URISyntaxException;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import java.io.PrintStream;

/**
 * The application's main frame.
 */
public class ErrorView extends FrameView {

    public ErrorView(SingleFrameApplication app, Exception ex) {
        super(app);

        initComponents();

        getFrame().setResizable(false);
        getFrame().pack();
        
        String report = "McURL has encountered an error. Please report the following error message on " +
            "the Minecraft \nforums or Bukkit forums, or send an email report with the title " + 
            "\"McURL Crash Report\" to: \ntad.hardesty@platymuus.com.\n\n";
        
        report += "OS: " + System.getProperty("os.name") + ", " + System.getProperty("os.version") + ", " + System.getProperty("os.arch") + "\n";
        report += "Java: " + System.getProperty("java.vendor") + ", " + System.getProperty("java.version") + "\n";
        report += "File stats: \n";
        report += "\tToplevel file = " + McUrlApp.toplevelFile + "\n";
        report += "\tAbsolute working dir = " + new File(".").getAbsolutePath() + "\n";
        try {
            report += "\tCanonical working dir = " + new File(".").getCanonicalPath() + "\n";
        }
        catch (IOException ex1) {
            report += "\tIOException retreiving canonical working dir: " + ex1.getMessage() + "\n";
        }
        try {
            report += "\tThis jarfile = " + McUrlApp.class.getProtectionDomain().getCodeSource().getLocation().toURI() + "\n";
        }
        catch (URISyntaxException ex1) {
            report += "\tURISyntaxException retreiving this jarfile: " + ex1.getMessage() + "\n";
        }
        File mcJar = new File("minecraft.jar");
        report += "\tminecraft.jar = " + mcJar.exists() + ", " + mcJar.lastModified() + "\n";
        report += "\n";

        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        ex.printStackTrace(new PrintStream(baos));
        report += baos.toString();
        
        errorPane.setText(report.replace("\t", "    "));
        errorPane.setSelectionStart(0);
        errorPane.setSelectionEnd(0);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        titleLabel = new javax.swing.JLabel();
        aboutLabel = new javax.swing.JLabel();
        jScrollPane2 = new javax.swing.JScrollPane();
        errorPane = new javax.swing.JEditorPane();
        jScrollPane1 = new javax.swing.JScrollPane();
        jTextPane1 = new javax.swing.JTextPane();

        mainPanel.setName("mainPanel"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(com.platymuus.mcurl.McUrlApp.class).getContext().getResourceMap(ErrorView.class);
        titleLabel.setFont(resourceMap.getFont("titleLabel.font")); // NOI18N
        titleLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        titleLabel.setText(resourceMap.getString("titleLabel.text")); // NOI18N
        titleLabel.setName("titleLabel"); // NOI18N

        aboutLabel.setFont(resourceMap.getFont("aboutLabel.font")); // NOI18N
        aboutLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aboutLabel.setText(resourceMap.getString("aboutLabel.text")); // NOI18N
        aboutLabel.setToolTipText(resourceMap.getString("aboutLabel.toolTipText")); // NOI18N
        aboutLabel.setName("aboutLabel"); // NOI18N

        jScrollPane2.setName("jScrollPane2"); // NOI18N

        errorPane.setEditable(false);
        errorPane.setName("errorPane"); // NOI18N
        jScrollPane2.setViewportView(errorPane);

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(aboutLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 480, Short.MAX_VALUE)
                .addContainerGap())
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(titleLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 480, Short.MAX_VALUE)
                .addContainerGap())
            .addComponent(jScrollPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 500, Short.MAX_VALUE)
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGap(6, 6, 6)
                .addComponent(titleLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jScrollPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 225, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(aboutLabel)
                .addGap(6, 6, 6))
        );

        jScrollPane1.setName("jScrollPane1"); // NOI18N

        jTextPane1.setName("jTextPane1"); // NOI18N
        jScrollPane1.setViewportView(jTextPane1);

        setComponent(mainPanel);
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel aboutLabel;
    private javax.swing.JEditorPane errorPane;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JTextPane jTextPane1;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JLabel titleLabel;
    // End of variables declaration//GEN-END:variables
}
